# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .diagnosis import Diagnosis
from .diagnosis_create import DiagnosisCreate
from .diagnosis_id import DiagnosisId
from .diagnosis_not_found_error import DiagnosisNotFoundError
from .diagnosis_type_code import DiagnosisTypeCode
from .standalone_diagnosis_create import StandaloneDiagnosisCreate

__all__ = [
    "Diagnosis",
    "DiagnosisCreate",
    "DiagnosisId",
    "DiagnosisNotFoundError",
    "DiagnosisTypeCode",
    "StandaloneDiagnosisCreate",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validation_error import HttpRequestValidationError
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.request_validation_error import RequestValidationError
from ....encounters.resources.v_4.errors.encounter_external_id_uniqueness_error import (
    EncounterExternalIdUniquenessError,
)
from ....encounters.resources.v_4.errors.encounter_patient_control_number_uniqueness_error import (
    EncounterPatientControlNumberUniquenessError,
)
from ....encounters.resources.v_4.errors.invalid_tag_names_error import InvalidTagNamesError
from ....encounters.resources.v_4.errors.schema_instance_validation_http_failure import (
    SchemaInstanceValidationHttpFailure,
)
from ....encounters.resources.v_4.types.encounter import Encounter
from ....encounters.resources.v_4.types.encounter_external_id_uniqueness_error_type import (
    EncounterExternalIdUniquenessErrorType,
)
from ....encounters.resources.v_4.types.encounter_patient_control_number_uniqueness_error_type import (
    EncounterPatientControlNumberUniquenessErrorType,
)
from ....encounters.resources.v_4.types.invalid_tag_names_error_type import InvalidTagNamesErrorType
from ....encounters.resources.v_4.types.schema_instance_validation_failure import SchemaInstanceValidationFailure
from .types.medication_dispense_create import MedicationDispenseCreate

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self, *, request: MedicationDispenseCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[Encounter]:
        """
        Parameters
        ----------
        request : MedicationDispenseCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[Encounter]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/medication-dispense/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                Encounter,
                parse_obj_as(
                    type_=Encounter,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        RequestValidationError,
                        parse_obj_as(
                            type_=RequestValidationError,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EncounterExternalIdUniquenessError":
                raise EncounterExternalIdUniquenessError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EncounterExternalIdUniquenessErrorType,
                        parse_obj_as(
                            type_=EncounterExternalIdUniquenessErrorType,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EncounterPatientControlNumberUniquenessError":
                raise EncounterPatientControlNumberUniquenessError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EncounterPatientControlNumberUniquenessErrorType,
                        parse_obj_as(
                            type_=EncounterPatientControlNumberUniquenessErrorType,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "InvalidTagNamesError":
                raise InvalidTagNamesError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        InvalidTagNamesErrorType,
                        parse_obj_as(
                            type_=InvalidTagNamesErrorType,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self, *, request: MedicationDispenseCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[Encounter]:
        """
        Parameters
        ----------
        request : MedicationDispenseCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[Encounter]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/medication-dispense/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                Encounter,
                parse_obj_as(
                    type_=Encounter,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        RequestValidationError,
                        parse_obj_as(
                            type_=RequestValidationError,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EncounterExternalIdUniquenessError":
                raise EncounterExternalIdUniquenessError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EncounterExternalIdUniquenessErrorType,
                        parse_obj_as(
                            type_=EncounterExternalIdUniquenessErrorType,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EncounterPatientControlNumberUniquenessError":
                raise EncounterPatientControlNumberUniquenessError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EncounterPatientControlNumberUniquenessErrorType,
                        parse_obj_as(
                            type_=EncounterPatientControlNumberUniquenessErrorType,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        SchemaInstanceValidationFailure,
                        parse_obj_as(
                            type_=SchemaInstanceValidationFailure,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "InvalidTagNamesError":
                raise InvalidTagNamesError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        InvalidTagNamesErrorType,
                        parse_obj_as(
                            type_=InvalidTagNamesErrorType,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    Payer,
    PayerId,
    PayerIdentifier,
    PayerIdentifier_PayerInfo,
    PayerIdentifier_PayerUuid,
    PayerInfo,
    PayerName,
    PayerPage,
    PayerUuid,
)

__all__ = [
    "Payer",
    "PayerId",
    "PayerIdentifier",
    "PayerIdentifier_PayerInfo",
    "PayerIdentifier_PayerUuid",
    "PayerInfo",
    "PayerName",
    "PayerPage",
    "PayerUuid",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AuthorizedSignatoryUpdate_Set(UniversalBaseModel):
    type: typing.Literal["set"] = "set"
    first_name: typing.Optional[str] = None
    last_name: typing.Optional[str] = None
    title: typing.Optional[str] = None
    email: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    fax: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AuthorizedSignatoryUpdate_Remove(UniversalBaseModel):
    type: typing.Literal["remove"] = "remove"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


AuthorizedSignatoryUpdate = typing.Union[AuthorizedSignatoryUpdate_Set, AuthorizedSignatoryUpdate_Remove]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....appointments.resources.v_1.types.mutable_appointment import MutableAppointment
from .....coverages.resources.v_1.types.mutable_coverage import MutableCoverage
from .....patients.resources.v_1.types.patient import Patient


class PatientListItem(UniversalBaseModel):
    patient: Patient
    primary_coverage: typing.Optional[MutableCoverage] = None
    next_appointment: typing.Optional[MutableAppointment] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .charge_capture import ChargeCapture
from .charge_capture_data import ChargeCaptureData
from .charge_capture_error import ChargeCaptureError
from .charge_capture_page import ChargeCapturePage
from .charge_capture_post_billed_change import ChargeCapturePostBilledChange
from .charge_capture_sort_field import ChargeCaptureSortField
from .charge_capture_status import ChargeCaptureStatus
from .charge_external_id_conflict_error_message import ChargeExternalIdConflictErrorMessage

__all__ = [
    "ChargeCapture",
    "ChargeCaptureData",
    "ChargeCaptureError",
    "ChargeCapturePage",
    "ChargeCapturePostBilledChange",
    "ChargeCaptureSortField",
    "ChargeCaptureStatus",
    "ChargeExternalIdConflictErrorMessage",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...commons.types.street_address_long_zip import StreetAddressLongZip
from .service_facility_id import ServiceFacilityId


class EncounterServiceFacility(UniversalBaseModel):
    """
    Examples
    --------
    import uuid

    from candid.resources.commons import State, StreetAddressLongZip
    from candid.resources.service_facility import EncounterServiceFacility

    EncounterServiceFacility(
        service_facility_id=uuid.UUID(
            "2861487b-232c-4ded-a874-616a5db0688f",
        ),
        organization_name="Test Organization",
        address=StreetAddressLongZip(
            address_1="123 Main St",
            address_2="Apt 1",
            city="New York",
            state=State.NY,
            zip_code="10001",
            zip_plus_four_code="1234",
        ),
    )
    """

    service_facility_id: ServiceFacilityId
    organization_name: str
    npi: typing.Optional[str] = pydantic.Field(default=None)
    """
    An NPI specific to the service facility if applicable, i.e. if it has one and is not under the billing provider's NPI.
    Box 32 section (a) of the CMS-1500 claim form.
    """

    address: StreetAddressLongZip = pydantic.Field()
    """
    zip_plus_four_code is required for service facility address. When the zip_plus_four_code is not available use "9998" as per CMS documentation.
    """

    secondary_identification: typing.Optional[str] = pydantic.Field(default=None)
    """
    An additional identifier for the service facility other than the facility's NPI. Some payers may require this field.
    Potential examples: state license number, provider commercial number, or location number.
    Box 32 section (b) of the CMS-1500 claim form.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .patient_payment import PatientPayment
from .patient_payment_id import PatientPaymentId
from .patient_payment_sort_field import PatientPaymentSortField
from .patient_payments_page import PatientPaymentsPage

__all__ = ["PatientPayment", "PatientPaymentId", "PatientPaymentSortField", "PatientPaymentsPage"]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class IntendedSubmissionMedium(str, enum.Enum):
    """
    The medium (paper or electronic) via which we intended to submit the claim. The clearinghouse to which we sent the claim may use a different medium in certain cases, e.g., if the payer does not support electronic claims.
    """

    PAPER = "paper"
    ELECTRONIC = "electronic"
    _UNKNOWN = "__INTENDEDSUBMISSIONMEDIUM_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "IntendedSubmissionMedium":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        paper: typing.Callable[[], T_Result],
        electronic: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is IntendedSubmissionMedium.PAPER:
            return paper()
        if self is IntendedSubmissionMedium.ELECTRONIC:
            return electronic()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ExternalProviderType(str, enum.Enum):
    PRIMARY = "PRIMARY"
    REFERRING = "REFERRING"
    ATTENDING = "ATTENDING"
    _UNKNOWN = "__EXTERNALPROVIDERTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExternalProviderType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        primary: typing.Callable[[], T_Result],
        referring: typing.Callable[[], T_Result],
        attending: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExternalProviderType.PRIMARY:
            return primary()
        if self is ExternalProviderType.REFERRING:
            return referring()
        if self is ExternalProviderType.ATTENDING:
            return attending()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.encounter_external_id_uniqueness_error_type import EncounterExternalIdUniquenessErrorType


class EncounterExternalIdUniquenessError(ApiError):
    def __init__(
        self, body: EncounterExternalIdUniquenessErrorType, headers: typing.Optional[typing.Dict[str, str]] = None
    ):
        super().__init__(status_code=422, headers=headers, body=body)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ServiceAuthorizationExceptionCode(str, enum.Enum):
    """
    Required when mandated by government law or regulation to obtain authorization for specific service(s) but, for the
    reasons listed in one of the enum values, the service was performed without obtaining the authorization.
    """

    C_1 = "1"
    """
    Immediate/Urgent Care
    """

    C_2 = "2"
    """
    Services Rendered in a Retroactive Period
    """

    C_3 = "3"
    """
    Emergency Care
    """

    C_4 = "4"
    """
    Client has Temporary Medicaid
    """

    C_5 = "5"
    """
    Request from County for Second Opinion to Determine if Recipient Can Work
    """

    C_6 = "6"
    """
    Request for Override Pending
    """

    C_7 = "7"
    """
    Special Handling
    """

    _UNKNOWN = "__SERVICEAUTHORIZATIONEXCEPTIONCODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ServiceAuthorizationExceptionCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_1: typing.Callable[[], T_Result],
        c_2: typing.Callable[[], T_Result],
        c_3: typing.Callable[[], T_Result],
        c_4: typing.Callable[[], T_Result],
        c_5: typing.Callable[[], T_Result],
        c_6: typing.Callable[[], T_Result],
        c_7: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ServiceAuthorizationExceptionCode.C_1:
            return c_1()
        if self is ServiceAuthorizationExceptionCode.C_2:
            return c_2()
        if self is ServiceAuthorizationExceptionCode.C_3:
            return c_3()
        if self is ServiceAuthorizationExceptionCode.C_4:
            return c_4()
        if self is ServiceAuthorizationExceptionCode.C_5:
            return c_5()
        if self is ServiceAuthorizationExceptionCode.C_6:
            return c_6()
        if self is ServiceAuthorizationExceptionCode.C_7:
            return c_7()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .payer_plan_group_already_exists_http_error import PayerPlanGroupAlreadyExistsHttpError

__all__ = ["PayerPlanGroupAlreadyExistsHttpError"]



# This file was auto-generated by Fern from our API Definition.

import typing

from .......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .......core.request_options import RequestOptions
from .raw_client import AsyncRawV1Client, RawV1Client
from .types.image import Image
from .types.image_id import ImageId
from .types.mutable_image import MutableImage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV1Client
        """
        return self._raw_client

    def create(self, *, request: MutableImage, request_options: typing.Optional[RequestOptions] = None) -> Image:
        """
        Adds an image.  VersionConflictError is returned if a front or back of this coverage already exists.

        Parameters
        ----------
        request : MutableImage

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Image

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.images.resources.v_1 import (
            ImageStatus,
            MutableImage,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.images.v_1.create(
            request=MutableImage(
                file_name="file_name",
                display_name="display_name",
                file_type="file_type",
                status=ImageStatus.PENDING,
            ),
        )
        """
        _response = self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    def get(self, id: ImageId, *, request_options: typing.Optional[RequestOptions] = None) -> Image:
        """
        Gets an image by imageId.

        Parameters
        ----------
        id : ImageId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Image

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.images.v_1.get(
            id="id",
        )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data

    def update(
        self,
        id: ImageId,
        version: str,
        *,
        request: MutableImage,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Image:
        """
        Updates an Image.  The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : ImageId

        version : str

        request : MutableImage

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Image

        Examples
        --------
        from candid import CandidApiClient
        from candid.resources.pre_encounter.resources.images.resources.v_1 import (
            ImageStatus,
            MutableImage,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.images.v_1.update(
            id="id",
            version="version",
            request=MutableImage(
                file_name="file_name",
                display_name="display_name",
                file_type="file_type",
                status=ImageStatus.PENDING,
            ),
        )
        """
        _response = self._raw_client.update(id, version, request=request, request_options=request_options)
        return _response.data

    def deactivate(self, id: ImageId, version: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Sets an Image as deactivated.  The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : ImageId

        version : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.images.v_1.deactivate(
            id="id",
            version="version",
        )
        """
        _response = self._raw_client.deactivate(id, version, request_options=request_options)
        return _response.data

    def get_multi(
        self,
        *,
        patient_id: typing.Optional[str] = None,
        coverage_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[Image]:
        """
        Searches for images that match the query parameters.

        Parameters
        ----------
        patient_id : typing.Optional[str]

        coverage_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Image]

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.pre_encounter.images.v_1.get_multi()
        """
        _response = self._raw_client.get_multi(
            patient_id=patient_id, coverage_id=coverage_id, request_options=request_options
        )
        return _response.data


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV1Client
        """
        return self._raw_client

    async def create(self, *, request: MutableImage, request_options: typing.Optional[RequestOptions] = None) -> Image:
        """
        Adds an image.  VersionConflictError is returned if a front or back of this coverage already exists.

        Parameters
        ----------
        request : MutableImage

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Image

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.images.resources.v_1 import (
            ImageStatus,
            MutableImage,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.images.v_1.create(
                request=MutableImage(
                    file_name="file_name",
                    display_name="display_name",
                    file_type="file_type",
                    status=ImageStatus.PENDING,
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    async def get(self, id: ImageId, *, request_options: typing.Optional[RequestOptions] = None) -> Image:
        """
        Gets an image by imageId.

        Parameters
        ----------
        id : ImageId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Image

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.images.v_1.get(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data

    async def update(
        self,
        id: ImageId,
        version: str,
        *,
        request: MutableImage,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> Image:
        """
        Updates an Image.  The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : ImageId

        version : str

        request : MutableImage

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Image

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient
        from candid.resources.pre_encounter.resources.images.resources.v_1 import (
            ImageStatus,
            MutableImage,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.images.v_1.update(
                id="id",
                version="version",
                request=MutableImage(
                    file_name="file_name",
                    display_name="display_name",
                    file_type="file_type",
                    status=ImageStatus.PENDING,
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(id, version, request=request, request_options=request_options)
        return _response.data

    async def deactivate(
        self, id: ImageId, version: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Sets an Image as deactivated.  The path must contain the most recent version to prevent races.

        Parameters
        ----------
        id : ImageId

        version : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.images.v_1.deactivate(
                id="id",
                version="version",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.deactivate(id, version, request_options=request_options)
        return _response.data

    async def get_multi(
        self,
        *,
        patient_id: typing.Optional[str] = None,
        coverage_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[Image]:
        """
        Searches for images that match the query parameters.

        Parameters
        ----------
        patient_id : typing.Optional[str]

        coverage_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Image]

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.pre_encounter.images.v_1.get_multi()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_multi(
            patient_id=patient_id, coverage_id=coverage_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.patient_external_id import PatientExternalId
from .....invoices.resources.v_2.types.invoice_item_create import InvoiceItemCreate
from .....invoices.resources.v_2.types.invoice_status import InvoiceStatus
from .....payment_account_configs.types.payment_account_config_id import PaymentAccountConfigId


class CreateImportInvoiceRequest(UniversalBaseModel):
    external_payment_account_config_id: PaymentAccountConfigId
    patient_external_id: PatientExternalId
    external_customer_identifier: str = pydantic.Field()
    """
    Id of the customer in the source system
    """

    note: typing.Optional[str] = None
    due_date: typing.Optional[dt.date] = pydantic.Field(default=None)
    """
    If given as None, days_until_due in the payment config will be used to create a default date
    """

    items: typing.List[InvoiceItemCreate]
    status: InvoiceStatus
    external_identifier: str = pydantic.Field()
    """
    Id of the invoice being imported in the source system. Warning - This field CANNOT be updated.
    """

    customer_invoice_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Link to the patient view of the invoice in the third-party service
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import ClinicalTrial, ClinicalTrialPhase, MutableClinicalTrial

__all__ = ["ClinicalTrial", "ClinicalTrialPhase", "MutableClinicalTrial"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .organization_provider_create_v_2 import OrganizationProviderCreateV2
from .organization_provider_page_v_2 import OrganizationProviderPageV2
from .organization_provider_update_v_2 import OrganizationProviderUpdateV2
from .organization_provider_v_2 import OrganizationProviderV2

__all__ = [
    "OrganizationProviderCreateV2",
    "OrganizationProviderPageV2",
    "OrganizationProviderUpdateV2",
    "OrganizationProviderV2",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import Payee, PayeeIdentifier, PayeeIdentifier_CmsPlanId, PayeeIdentifier_Npi, PayeeIdentifier_Tin

__all__ = ["Payee", "PayeeIdentifier", "PayeeIdentifier_CmsPlanId", "PayeeIdentifier_Npi", "PayeeIdentifier_Tin"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    EncounterHasExistingGuarantorErrorType,
    Guarantor,
    GuarantorBase,
    GuarantorCreate,
    GuarantorId,
    GuarantorUpdate,
)
from .errors import EncounterHasExistingGuarantorError

__all__ = [
    "EncounterHasExistingGuarantorError",
    "EncounterHasExistingGuarantorErrorType",
    "Guarantor",
    "GuarantorBase",
    "GuarantorCreate",
    "GuarantorId",
    "GuarantorUpdate",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .identifier import Identifier
from .identifier_base import IdentifierBase
from .identifier_code import IdentifierCode
from .identifier_create import IdentifierCreate
from .identifier_id import IdentifierId
from .identifier_update import IdentifierUpdate
from .identifier_value import (
    IdentifierValue,
    IdentifierValue_MedicaidProviderIdentifier,
    IdentifierValue_MedicareProviderIdentifier,
)
from .medicaid_provider_identifier import MedicaidProviderIdentifier
from .medicare_provider_identifier import MedicareProviderIdentifier
from .updatable_identifier import (
    UpdatableIdentifier,
    UpdatableIdentifier_Add,
    UpdatableIdentifier_Remove,
    UpdatableIdentifier_Update,
)

__all__ = [
    "Identifier",
    "IdentifierBase",
    "IdentifierCode",
    "IdentifierCreate",
    "IdentifierId",
    "IdentifierUpdate",
    "IdentifierValue",
    "IdentifierValue_MedicaidProviderIdentifier",
    "IdentifierValue_MedicareProviderIdentifier",
    "MedicaidProviderIdentifier",
    "MedicareProviderIdentifier",
    "UpdatableIdentifier",
    "UpdatableIdentifier_Add",
    "UpdatableIdentifier_Remove",
    "UpdatableIdentifier_Update",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..... import core
from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....commons.types.encounter_id import EncounterId
from .types.attachment_id import AttachmentId
from .types.encounter_attachment import EncounterAttachment
from .types.encounter_attachment_type import EncounterAttachmentType

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[typing.List[EncounterAttachment]]:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[EncounterAttachment]]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-attachments/v1/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[EncounterAttachment],
                parse_obj_as(
                    type_=typing.List[EncounterAttachment],  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        encounter_id: EncounterId,
        *,
        attachment_file: core.File,
        attachment_type: EncounterAttachmentType,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[AttachmentId]:
        """
        Uploads a file to the encounter. The file will be stored in the
        encounter's attachments.

        Parameters
        ----------
        encounter_id : EncounterId

        attachment_file : core.File
            See core.File for more documentation

        attachment_type : EncounterAttachmentType

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AttachmentId]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-attachments/v1/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PUT",
            data={
                "attachment_type": attachment_type,
            },
            files={
                "attachment_file": attachment_file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                AttachmentId,
                parse_obj_as(
                    type_=AttachmentId,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self,
        encounter_id: EncounterId,
        *,
        attachment_id: AttachmentId,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        attachment_id : AttachmentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/encounter-attachments/v1/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            json={
                "attachment_id": attachment_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return HttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self, encounter_id: EncounterId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[typing.List[EncounterAttachment]]:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[EncounterAttachment]]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-attachments/v1/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                typing.List[EncounterAttachment],
                parse_obj_as(
                    type_=typing.List[EncounterAttachment],  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        encounter_id: EncounterId,
        *,
        attachment_file: core.File,
        attachment_type: EncounterAttachmentType,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[AttachmentId]:
        """
        Uploads a file to the encounter. The file will be stored in the
        encounter's attachments.

        Parameters
        ----------
        encounter_id : EncounterId

        attachment_file : core.File
            See core.File for more documentation

        attachment_type : EncounterAttachmentType

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AttachmentId]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-attachments/v1/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PUT",
            data={
                "attachment_type": attachment_type,
            },
            files={
                "attachment_file": attachment_file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                AttachmentId,
                parse_obj_as(
                    type_=AttachmentId,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self,
        encounter_id: EncounterId,
        *,
        attachment_id: AttachmentId,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Parameters
        ----------
        encounter_id : EncounterId

        attachment_id : AttachmentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/encounter-attachments/v1/{jsonable_encoder(encounter_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            json={
                "attachment_id": attachment_id,
            },
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return AsyncHttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class TaskCategory(str, enum.Enum):
    OTHER = "other"
    PROVIDER_CREDENTIALING = "provider_credentialing"
    AUTHORIZATION_REQUIRED = "authorization_required"
    INACTIVE_COVERAGE = "inactive_coverage"
    UNKNOWN_ELIGIBILITY_OR_PATIENT_NOT_FOUND = "unknown_eligibility_or_patient_not_found"
    INCORRECT_MEMBER_ID = "incorrect_member_id"
    DOCUMENTATION_ADDENDUM_REQUEST = "documentation_addendum_request"
    COORDINATION_OF_BENEFITS = "coordination_of_benefits"
    MISSING_OR_INCORRECT_GENDER = "missing_or_incorrect_gender"
    INCORRECT_DATE_OF_BIRTH = "incorrect_date_of_birth"
    INCORRECT_PAYER = "incorrect_payer"
    INCORRECT_NAME = "incorrect_name"
    INVALID_DIAGNOSIS_CODE = "invalid_diagnosis_code"
    NON_COVERED_DIAGNOSIS_CODES = "non_covered_diagnosis_codes"
    INFORMATION_REQUESTED_FROM_PATIENT = "information_requested_from_patient"
    INCORRECT_RENDERING_PROVIDER_INFO = "incorrect_rendering_provider_info"
    MISSING_OR_INCORRECT_MODIFIER = "missing_or_incorrect_modifier"
    CODING_FREQUENCY_ERROR = "coding_frequency_error"
    INCORRECT_PATIENT_ADDRESS = "incorrect_patient_address"
    MULTIPLE_EM_CLAIMS = "multiple_em_claims"
    MISSING_OR_INCORRECT_CHARGE_AMOUNT = "missing_or_incorrect_charge_amount"
    MEDICAL_RECORDS_REQUEST = "medical_records_request"
    PROVIDER_ENROLLMENT_OR_CONTRACTING = "provider_enrollment_or_contracting"
    MISSING_OR_INCORRECT_GROUP_NUMBER = "missing_or_incorrect_group_number"
    MISSING_DIAGNOSIS_CODES = "missing_diagnosis_codes"
    MISSING_PATIENT_AUTHORIZATION = "missing_patient_authorization"
    INCORRECT_BILLING_PROVIDER_INFO = "incorrect_billing_provider_info"
    INCORRECT_PROCEDURE_CODE = "incorrect_procedure_code"
    INCORRECT_QUANTITY = "incorrect_quantity"
    INCORRECT_PLACE_OF_SERVICE_CODE = "incorrect_place_of_service_code"
    INCORRECT_SERVICE_FACILITY_INFO = "incorrect_service_facility_info"
    INCORRECT_DATE_OF_SERVICE = "incorrect_date_of_service"
    MISSING_OR_INCORRECT_NDC = "missing_or_incorrect_ndc"
    PATIENT_COLLECTIONS = "patient_collections"
    SUBMIT_TO_SECONDARY = "submit_to_secondary"
    TRANSIENT_SERVER_ERROR = "transient_server_error"
    MISSING_REMITTANCE_ENROLLMENT = "missing_remittance_enrollment"
    MISSING_CLAIMS_ENROLLMENT = "missing_claims_enrollment"
    HELD_BY_CUSTOMER = "held_by_customer"
    PENDING_MANUAL_REMIT_POSTING = "pending_manual_remit_posting"
    INCORRECT_REFERRING_PROVIDER_INFO = "incorrect_referring_provider_info"
    PAYER_CONFIGURATION_ERROR = "payer_configuration_error"
    _UNKNOWN = "__TASKCATEGORY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "TaskCategory":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        other: typing.Callable[[], T_Result],
        provider_credentialing: typing.Callable[[], T_Result],
        authorization_required: typing.Callable[[], T_Result],
        inactive_coverage: typing.Callable[[], T_Result],
        unknown_eligibility_or_patient_not_found: typing.Callable[[], T_Result],
        incorrect_member_id: typing.Callable[[], T_Result],
        documentation_addendum_request: typing.Callable[[], T_Result],
        coordination_of_benefits: typing.Callable[[], T_Result],
        missing_or_incorrect_gender: typing.Callable[[], T_Result],
        incorrect_date_of_birth: typing.Callable[[], T_Result],
        incorrect_payer: typing.Callable[[], T_Result],
        incorrect_name: typing.Callable[[], T_Result],
        invalid_diagnosis_code: typing.Callable[[], T_Result],
        non_covered_diagnosis_codes: typing.Callable[[], T_Result],
        information_requested_from_patient: typing.Callable[[], T_Result],
        incorrect_rendering_provider_info: typing.Callable[[], T_Result],
        missing_or_incorrect_modifier: typing.Callable[[], T_Result],
        coding_frequency_error: typing.Callable[[], T_Result],
        incorrect_patient_address: typing.Callable[[], T_Result],
        multiple_em_claims: typing.Callable[[], T_Result],
        missing_or_incorrect_charge_amount: typing.Callable[[], T_Result],
        medical_records_request: typing.Callable[[], T_Result],
        provider_enrollment_or_contracting: typing.Callable[[], T_Result],
        missing_or_incorrect_group_number: typing.Callable[[], T_Result],
        missing_diagnosis_codes: typing.Callable[[], T_Result],
        missing_patient_authorization: typing.Callable[[], T_Result],
        incorrect_billing_provider_info: typing.Callable[[], T_Result],
        incorrect_procedure_code: typing.Callable[[], T_Result],
        incorrect_quantity: typing.Callable[[], T_Result],
        incorrect_place_of_service_code: typing.Callable[[], T_Result],
        incorrect_service_facility_info: typing.Callable[[], T_Result],
        incorrect_date_of_service: typing.Callable[[], T_Result],
        missing_or_incorrect_ndc: typing.Callable[[], T_Result],
        patient_collections: typing.Callable[[], T_Result],
        submit_to_secondary: typing.Callable[[], T_Result],
        transient_server_error: typing.Callable[[], T_Result],
        missing_remittance_enrollment: typing.Callable[[], T_Result],
        missing_claims_enrollment: typing.Callable[[], T_Result],
        held_by_customer: typing.Callable[[], T_Result],
        pending_manual_remit_posting: typing.Callable[[], T_Result],
        incorrect_referring_provider_info: typing.Callable[[], T_Result],
        payer_configuration_error: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is TaskCategory.OTHER:
            return other()
        if self is TaskCategory.PROVIDER_CREDENTIALING:
            return provider_credentialing()
        if self is TaskCategory.AUTHORIZATION_REQUIRED:
            return authorization_required()
        if self is TaskCategory.INACTIVE_COVERAGE:
            return inactive_coverage()
        if self is TaskCategory.UNKNOWN_ELIGIBILITY_OR_PATIENT_NOT_FOUND:
            return unknown_eligibility_or_patient_not_found()
        if self is TaskCategory.INCORRECT_MEMBER_ID:
            return incorrect_member_id()
        if self is TaskCategory.DOCUMENTATION_ADDENDUM_REQUEST:
            return documentation_addendum_request()
        if self is TaskCategory.COORDINATION_OF_BENEFITS:
            return coordination_of_benefits()
        if self is TaskCategory.MISSING_OR_INCORRECT_GENDER:
            return missing_or_incorrect_gender()
        if self is TaskCategory.INCORRECT_DATE_OF_BIRTH:
            return incorrect_date_of_birth()
        if self is TaskCategory.INCORRECT_PAYER:
            return incorrect_payer()
        if self is TaskCategory.INCORRECT_NAME:
            return incorrect_name()
        if self is TaskCategory.INVALID_DIAGNOSIS_CODE:
            return invalid_diagnosis_code()
        if self is TaskCategory.NON_COVERED_DIAGNOSIS_CODES:
            return non_covered_diagnosis_codes()
        if self is TaskCategory.INFORMATION_REQUESTED_FROM_PATIENT:
            return information_requested_from_patient()
        if self is TaskCategory.INCORRECT_RENDERING_PROVIDER_INFO:
            return incorrect_rendering_provider_info()
        if self is TaskCategory.MISSING_OR_INCORRECT_MODIFIER:
            return missing_or_incorrect_modifier()
        if self is TaskCategory.CODING_FREQUENCY_ERROR:
            return coding_frequency_error()
        if self is TaskCategory.INCORRECT_PATIENT_ADDRESS:
            return incorrect_patient_address()
        if self is TaskCategory.MULTIPLE_EM_CLAIMS:
            return multiple_em_claims()
        if self is TaskCategory.MISSING_OR_INCORRECT_CHARGE_AMOUNT:
            return missing_or_incorrect_charge_amount()
        if self is TaskCategory.MEDICAL_RECORDS_REQUEST:
            return medical_records_request()
        if self is TaskCategory.PROVIDER_ENROLLMENT_OR_CONTRACTING:
            return provider_enrollment_or_contracting()
        if self is TaskCategory.MISSING_OR_INCORRECT_GROUP_NUMBER:
            return missing_or_incorrect_group_number()
        if self is TaskCategory.MISSING_DIAGNOSIS_CODES:
            return missing_diagnosis_codes()
        if self is TaskCategory.MISSING_PATIENT_AUTHORIZATION:
            return missing_patient_authorization()
        if self is TaskCategory.INCORRECT_BILLING_PROVIDER_INFO:
            return incorrect_billing_provider_info()
        if self is TaskCategory.INCORRECT_PROCEDURE_CODE:
            return incorrect_procedure_code()
        if self is TaskCategory.INCORRECT_QUANTITY:
            return incorrect_quantity()
        if self is TaskCategory.INCORRECT_PLACE_OF_SERVICE_CODE:
            return incorrect_place_of_service_code()
        if self is TaskCategory.INCORRECT_SERVICE_FACILITY_INFO:
            return incorrect_service_facility_info()
        if self is TaskCategory.INCORRECT_DATE_OF_SERVICE:
            return incorrect_date_of_service()
        if self is TaskCategory.MISSING_OR_INCORRECT_NDC:
            return missing_or_incorrect_ndc()
        if self is TaskCategory.PATIENT_COLLECTIONS:
            return patient_collections()
        if self is TaskCategory.SUBMIT_TO_SECONDARY:
            return submit_to_secondary()
        if self is TaskCategory.TRANSIENT_SERVER_ERROR:
            return transient_server_error()
        if self is TaskCategory.MISSING_REMITTANCE_ENROLLMENT:
            return missing_remittance_enrollment()
        if self is TaskCategory.MISSING_CLAIMS_ENROLLMENT:
            return missing_claims_enrollment()
        if self is TaskCategory.HELD_BY_CUSTOMER:
            return held_by_customer()
        if self is TaskCategory.PENDING_MANUAL_REMIT_POSTING:
            return pending_manual_remit_posting()
        if self is TaskCategory.INCORRECT_REFERRING_PROVIDER_INFO:
            return incorrect_referring_provider_info()
        if self is TaskCategory.PAYER_CONFIGURATION_ERROR:
            return payer_configuration_error()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ChargeCapture,
    ChargeCaptureData,
    ChargeCaptureError,
    ChargeCapturePage,
    ChargeCapturePostBilledChange,
    ChargeCaptureSortField,
    ChargeCaptureStatus,
    ChargeExternalIdConflictErrorMessage,
)
from .errors import ChargeExternalIdConflictError

__all__ = [
    "ChargeCapture",
    "ChargeCaptureData",
    "ChargeCaptureError",
    "ChargeCapturePage",
    "ChargeCapturePostBilledChange",
    "ChargeCaptureSortField",
    "ChargeCaptureStatus",
    "ChargeExternalIdConflictError",
    "ChargeExternalIdConflictErrorMessage",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ReportTypeCode(str, enum.Enum):
    C_03 = "03"
    """
    Report Justifying Treatment Beyond Utilization Guidelines
    """

    C_04 = "04"
    """
    Drugs Administered
    """

    C_05 = "05"
    """
    Treatment Diagnosis
    """

    C_06 = "06"
    """
    Initial Assessment
    """

    C_07 = "07"
    """
    Functional Goals
    """

    C_08 = "08"
    """
    Plan of Treatment
    """

    C_09 = "09"
    """
    Progress Report
    """

    C_10 = "10"
    """
    Continued Treatment
    """

    C_11 = "11"
    """
    Chemical Analysis
    """

    C_13 = "13"
    """
    Certified Test Report
    """

    C_15 = "15"
    """
    Justification for Admission
    """

    C_21 = "21"
    """
    Recovery Plan
    """

    CA_3 = "A3"
    """
    Allergies/Sensitivities Document
    """

    CA_4 = "A4"
    """
    Autopsy Report
    """

    CAM = "AM"
    """
    Ambulance Certification
    """

    CAS = "AS"
    """
    Admission Summary
    """

    CB_2 = "B2"
    """
    Prescription
    """

    CB_3 = "B3"
    """
    Physician Order
    """

    CB_4 = "B4"
    """
    Referral Form
    """

    CBR = "BR"
    """
    Benchmark Testing Results
    """

    CBS = "BS"
    """
    Baseline
    """

    CBT = "BT"
    """
    Blanket Test Results
    """

    CCB = "CB"
    """
    Chiropractic Justification
    """

    CCK = "CK"
    """
    Consent Form(s)
    """

    CCT = "CT"
    """
    Certification
    """

    CD_2 = "D2"
    """
    Drug Profile Document
    """

    CDA = "DA"
    """
    Dental Models
    """

    CDB = "DB"
    """
    Durable Medical Equipment Prescription
    """

    CDG = "DG"
    """
    Diagnostic Report
    """

    CDJ = "DJ"
    """
    Discharge Monitoring Report
    """

    CDS = "DS"
    """
    Discharge Summary
    """

    CEB = "EB"
    """
    Explanation of Benefits (Coordination of Benefits or Medicare Secondary Payor)
    """

    CHC = "HC"
    """
    Health Certificate
    """

    CHR = "HR"
    """
    Health Clinic Records
    """

    CI_5 = "I5"
    """
    Immunization Record
    """

    CIR = "IR"
    """
    State School Immunization Records
    """

    CLA = "LA"
    """
    Laboratory Results
    """

    CM_1 = "M1"
    """
    Medical Record Attachment
    """

    CMT = "MT"
    """
    Models
    """

    CNN = "NN"
    """
    Nursing Notes
    """

    COB = "OB"
    """
    Operative Note
    """

    COC = "OC"
    """
    Oxygen Content Averaging Report
    """

    COD = "OD"
    """
    Orders and Treatments Document
    """

    COE = "OE"
    """
    Objective Physical Examination (including vital signs) Document
    """

    COX = "OX"
    """
    Oxygen Therapy Certification
    """

    COZ = "OZ"
    """
    Support Data for Claim
    """

    CP_4 = "P4"
    """
    Pathology Report
    """

    CP_5 = "P5"
    """
    Patient Medical History Document
    """

    CPE = "PE"
    """
    Parenteral or Enteral Certification
    """

    CPN = "PN"
    """
    Physical Therapy Notes
    """

    CPO = "PO"
    """
    Prosthetics or Orthotic Certification
    """

    CPQ = "PQ"
    """
    Paramedical Results
    """

    CPY = "PY"
    """
    Physician's Report
    """

    CPZ = "PZ"
    """
    Physical Therapy Certification
    """

    CRB = "RB"
    """
    Radiology Films
    """

    CRR = "RR"
    """
    Radiology Reports
    """

    CRT = "RT"
    """
    Report of Tests and Analysis Report
    """

    CRX = "RX"
    """
    Renewable Oxygen Content Averaging Report
    """

    CSG = "SG"
    """
    Symptoms Document
    """

    CV_5 = "V5"
    """
    Death Notification
    """

    CXP = "XP"
    """
    Photographs
    """

    _UNKNOWN = "__REPORTTYPECODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ReportTypeCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_03: typing.Callable[[], T_Result],
        c_04: typing.Callable[[], T_Result],
        c_05: typing.Callable[[], T_Result],
        c_06: typing.Callable[[], T_Result],
        c_07: typing.Callable[[], T_Result],
        c_08: typing.Callable[[], T_Result],
        c_09: typing.Callable[[], T_Result],
        c_10: typing.Callable[[], T_Result],
        c_11: typing.Callable[[], T_Result],
        c_13: typing.Callable[[], T_Result],
        c_15: typing.Callable[[], T_Result],
        c_21: typing.Callable[[], T_Result],
        ca_3: typing.Callable[[], T_Result],
        ca_4: typing.Callable[[], T_Result],
        cam: typing.Callable[[], T_Result],
        cas: typing.Callable[[], T_Result],
        cb_2: typing.Callable[[], T_Result],
        cb_3: typing.Callable[[], T_Result],
        cb_4: typing.Callable[[], T_Result],
        cbr: typing.Callable[[], T_Result],
        cbs: typing.Callable[[], T_Result],
        cbt: typing.Callable[[], T_Result],
        ccb: typing.Callable[[], T_Result],
        cck: typing.Callable[[], T_Result],
        cct: typing.Callable[[], T_Result],
        cd_2: typing.Callable[[], T_Result],
        cda: typing.Callable[[], T_Result],
        cdb: typing.Callable[[], T_Result],
        cdg: typing.Callable[[], T_Result],
        cdj: typing.Callable[[], T_Result],
        cds: typing.Callable[[], T_Result],
        ceb: typing.Callable[[], T_Result],
        chc: typing.Callable[[], T_Result],
        chr: typing.Callable[[], T_Result],
        ci_5: typing.Callable[[], T_Result],
        cir: typing.Callable[[], T_Result],
        cla: typing.Callable[[], T_Result],
        cm_1: typing.Callable[[], T_Result],
        cmt: typing.Callable[[], T_Result],
        cnn: typing.Callable[[], T_Result],
        cob: typing.Callable[[], T_Result],
        coc: typing.Callable[[], T_Result],
        cod: typing.Callable[[], T_Result],
        coe: typing.Callable[[], T_Result],
        cox: typing.Callable[[], T_Result],
        coz: typing.Callable[[], T_Result],
        cp_4: typing.Callable[[], T_Result],
        cp_5: typing.Callable[[], T_Result],
        cpe: typing.Callable[[], T_Result],
        cpn: typing.Callable[[], T_Result],
        cpo: typing.Callable[[], T_Result],
        cpq: typing.Callable[[], T_Result],
        cpy: typing.Callable[[], T_Result],
        cpz: typing.Callable[[], T_Result],
        crb: typing.Callable[[], T_Result],
        crr: typing.Callable[[], T_Result],
        crt: typing.Callable[[], T_Result],
        crx: typing.Callable[[], T_Result],
        csg: typing.Callable[[], T_Result],
        cv_5: typing.Callable[[], T_Result],
        cxp: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ReportTypeCode.C_03:
            return c_03()
        if self is ReportTypeCode.C_04:
            return c_04()
        if self is ReportTypeCode.C_05:
            return c_05()
        if self is ReportTypeCode.C_06:
            return c_06()
        if self is ReportTypeCode.C_07:
            return c_07()
        if self is ReportTypeCode.C_08:
            return c_08()
        if self is ReportTypeCode.C_09:
            return c_09()
        if self is ReportTypeCode.C_10:
            return c_10()
        if self is ReportTypeCode.C_11:
            return c_11()
        if self is ReportTypeCode.C_13:
            return c_13()
        if self is ReportTypeCode.C_15:
            return c_15()
        if self is ReportTypeCode.C_21:
            return c_21()
        if self is ReportTypeCode.CA_3:
            return ca_3()
        if self is ReportTypeCode.CA_4:
            return ca_4()
        if self is ReportTypeCode.CAM:
            return cam()
        if self is ReportTypeCode.CAS:
            return cas()
        if self is ReportTypeCode.CB_2:
            return cb_2()
        if self is ReportTypeCode.CB_3:
            return cb_3()
        if self is ReportTypeCode.CB_4:
            return cb_4()
        if self is ReportTypeCode.CBR:
            return cbr()
        if self is ReportTypeCode.CBS:
            return cbs()
        if self is ReportTypeCode.CBT:
            return cbt()
        if self is ReportTypeCode.CCB:
            return ccb()
        if self is ReportTypeCode.CCK:
            return cck()
        if self is ReportTypeCode.CCT:
            return cct()
        if self is ReportTypeCode.CD_2:
            return cd_2()
        if self is ReportTypeCode.CDA:
            return cda()
        if self is ReportTypeCode.CDB:
            return cdb()
        if self is ReportTypeCode.CDG:
            return cdg()
        if self is ReportTypeCode.CDJ:
            return cdj()
        if self is ReportTypeCode.CDS:
            return cds()
        if self is ReportTypeCode.CEB:
            return ceb()
        if self is ReportTypeCode.CHC:
            return chc()
        if self is ReportTypeCode.CHR:
            return chr()
        if self is ReportTypeCode.CI_5:
            return ci_5()
        if self is ReportTypeCode.CIR:
            return cir()
        if self is ReportTypeCode.CLA:
            return cla()
        if self is ReportTypeCode.CM_1:
            return cm_1()
        if self is ReportTypeCode.CMT:
            return cmt()
        if self is ReportTypeCode.CNN:
            return cnn()
        if self is ReportTypeCode.COB:
            return cob()
        if self is ReportTypeCode.COC:
            return coc()
        if self is ReportTypeCode.COD:
            return cod()
        if self is ReportTypeCode.COE:
            return coe()
        if self is ReportTypeCode.COX:
            return cox()
        if self is ReportTypeCode.COZ:
            return coz()
        if self is ReportTypeCode.CP_4:
            return cp_4()
        if self is ReportTypeCode.CP_5:
            return cp_5()
        if self is ReportTypeCode.CPE:
            return cpe()
        if self is ReportTypeCode.CPN:
            return cpn()
        if self is ReportTypeCode.CPO:
            return cpo()
        if self is ReportTypeCode.CPQ:
            return cpq()
        if self is ReportTypeCode.CPY:
            return cpy()
        if self is ReportTypeCode.CPZ:
            return cpz()
        if self is ReportTypeCode.CRB:
            return crb()
        if self is ReportTypeCode.CRR:
            return crr()
        if self is ReportTypeCode.CRT:
            return crt()
        if self is ReportTypeCode.CRX:
            return crx()
        if self is ReportTypeCode.CSG:
            return csg()
        if self is ReportTypeCode.CV_5:
            return cv_5()
        if self is ReportTypeCode.CXP:
            return cxp()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class MemberInfo(UniversalBaseModel):
    member_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Stedi requires that you supply at least one of these fields in the request: memberId, dateOfBirth, or lastName.  
    However, each payer has different requirements, so you should supply as many of the fields necessary for each payer 
    to identify the subscriber/dependent in their system.
    """

    first_name: str
    last_name: str
    date_of_birth: typing.Optional[dt.date] = pydantic.Field(default=None)
    """
    Stedi requires that you supply at least one of these fields in the request: memberId, dateOfBirth, or lastName.  
    However, each payer has different requirements, so you should supply as many of the fields necessary for each payer 
    to identify the subscriber/dependent in their system.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validation_error import HttpRequestValidationError
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.page_token import PageToken
from ....commons.types.request_validation_error import RequestValidationError
from .types.organization_service_facility import OrganizationServiceFacility
from .types.organization_service_facility_create import OrganizationServiceFacilityCreate
from .types.organization_service_facility_id import OrganizationServiceFacilityId
from .types.organization_service_facility_page import OrganizationServiceFacilityPage
from .types.organization_service_facility_update import OrganizationServiceFacilityUpdate

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self,
        organization_service_facility_id: OrganizationServiceFacilityId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrganizationServiceFacility]:
        """
        Parameters
        ----------
        organization_service_facility_id : OrganizationServiceFacilityId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrganizationServiceFacility]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/organization-service-facilities/v2/{jsonable_encoder(organization_service_facility_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacility,
                parse_obj_as(
                    type_=OrganizationServiceFacility,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrganizationServiceFacilityPage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Limit the number of results returned. Defaults to 100.

        name : typing.Optional[str]
            Filter to a name or a part of a name.

        page_token : typing.Optional[PageToken]
            The page token to continue paging through a previous request.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrganizationServiceFacilityPage]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/organization-service-facilities/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "name": name,
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacilityPage,
                parse_obj_as(
                    type_=OrganizationServiceFacilityPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self, *, request: OrganizationServiceFacilityCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[OrganizationServiceFacility]:
        """
        Parameters
        ----------
        request : OrganizationServiceFacilityCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrganizationServiceFacility]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/organization-service-facilities/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacility,
                parse_obj_as(
                    type_=OrganizationServiceFacility,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        RequestValidationError,
                        parse_obj_as(
                            type_=RequestValidationError,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        organization_service_facility_id: OrganizationServiceFacilityId,
        *,
        request: OrganizationServiceFacilityUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[OrganizationServiceFacility]:
        """
        Parameters
        ----------
        organization_service_facility_id : OrganizationServiceFacilityId

        request : OrganizationServiceFacilityUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[OrganizationServiceFacility]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/organization-service-facilities/v2/{jsonable_encoder(organization_service_facility_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacility,
                parse_obj_as(
                    type_=OrganizationServiceFacility,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        RequestValidationError,
                        parse_obj_as(
                            type_=RequestValidationError,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self,
        organization_service_facility_id: OrganizationServiceFacilityId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Parameters
        ----------
        organization_service_facility_id : OrganizationServiceFacilityId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/organization-service-facilities/v2/{jsonable_encoder(organization_service_facility_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return HttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self,
        organization_service_facility_id: OrganizationServiceFacilityId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrganizationServiceFacility]:
        """
        Parameters
        ----------
        organization_service_facility_id : OrganizationServiceFacilityId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrganizationServiceFacility]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/organization-service-facilities/v2/{jsonable_encoder(organization_service_facility_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacility,
                parse_obj_as(
                    type_=OrganizationServiceFacility,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrganizationServiceFacilityPage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Limit the number of results returned. Defaults to 100.

        name : typing.Optional[str]
            Filter to a name or a part of a name.

        page_token : typing.Optional[PageToken]
            The page token to continue paging through a previous request.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrganizationServiceFacilityPage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/organization-service-facilities/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "name": name,
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacilityPage,
                parse_obj_as(
                    type_=OrganizationServiceFacilityPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self, *, request: OrganizationServiceFacilityCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[OrganizationServiceFacility]:
        """
        Parameters
        ----------
        request : OrganizationServiceFacilityCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrganizationServiceFacility]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/organization-service-facilities/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacility,
                parse_obj_as(
                    type_=OrganizationServiceFacility,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        RequestValidationError,
                        parse_obj_as(
                            type_=RequestValidationError,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        organization_service_facility_id: OrganizationServiceFacilityId,
        *,
        request: OrganizationServiceFacilityUpdate,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[OrganizationServiceFacility]:
        """
        Parameters
        ----------
        organization_service_facility_id : OrganizationServiceFacilityId

        request : OrganizationServiceFacilityUpdate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[OrganizationServiceFacility]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/organization-service-facilities/v2/{jsonable_encoder(organization_service_facility_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                OrganizationServiceFacility,
                parse_obj_as(
                    type_=OrganizationServiceFacility,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        RequestValidationError,
                        parse_obj_as(
                            type_=RequestValidationError,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self,
        organization_service_facility_id: OrganizationServiceFacilityId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Parameters
        ----------
        organization_service_facility_id : OrganizationServiceFacilityId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/organization-service-facilities/v2/{jsonable_encoder(organization_service_facility_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return AsyncHttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.claim_id import ClaimId
from .....commons.types.date_range_optional_end import DateRangeOptionalEnd
from .....commons.types.decimal import Decimal
from .....commons.types.facility_type_code import FacilityTypeCode
from .....commons.types.procedure_modifier import ProcedureModifier
from .....commons.types.service_line_id import ServiceLineId
from .....commons.types.service_line_units import ServiceLineUnits
from .....diagnoses.types.diagnosis_id import DiagnosisId
from .....encounter_providers.resources.v_2.types.encounter_provider import EncounterProvider
from .....invoices.resources.v_2.types.invoice_info import InvoiceInfo
from .....invoices.types.invoice import Invoice
from .drug_identification import DrugIdentification
from .service_line_adjustment import ServiceLineAdjustment
from .service_line_denial_reason import ServiceLineDenialReason
from .service_line_era_data import ServiceLineEraData
from .test_result import TestResult


class ServiceLine(UniversalBaseModel):
    """
    Examples
    --------
    import datetime
    import uuid

    from candid.resources.commons import (
        DateRangeOptionalEnd,
        FacilityTypeCode,
        ProcedureModifier,
        ServiceLineUnits,
    )
    from candid.resources.invoices import Invoice, InvoiceItem, InvoiceStatus
    from candid.resources.service_lines.resources.v_2 import (
        DenialReasonContent,
        ServiceLine,
        ServiceLineAdjustment,
        ServiceLineDenialReason,
        ServiceLineEraData,
        TestResult,
        TestResultType,
    )

    ServiceLine(
        created_at=datetime.datetime.fromisoformat(
            "2023-01-01 00:00:00+00:00",
        ),
        modifiers=[ProcedureModifier.TWENTY_TWO],
        charge_amount_cents=10000,
        allowed_amount_cents=8000,
        insurance_balance_cents=0,
        patient_balance_cents=2000,
        paid_amount_cents=8000,
        patient_responsibility_cents=2000,
        diagnosis_id_zero=uuid.UUID(
            "4ac84bcd-12f5-4f86-a57b-e06749127c98",
        ),
        diagnosis_id_one=uuid.UUID(
            "eea5ca5a-8b43-45fd-8cbd-c6cc1103e759",
        ),
        diagnosis_id_two=uuid.UUID(
            "5c4aa029-2db9-4202-916e-e93c708f65ff",
        ),
        diagnosis_id_three=uuid.UUID(
            "81795126-a3ac-443c-b47e-7259a16ab4a2",
        ),
        service_line_era_data=ServiceLineEraData(
            service_line_adjustments=[
                ServiceLineAdjustment(
                    created_at=datetime.datetime.fromisoformat(
                        "2023-01-01 00:00:00+00:00",
                    ),
                    adjustment_group_code="CO",
                    adjustment_reason_code="CO",
                    adjustment_amount_cents=1000,
                    adjustment_note="test_note",
                )
            ],
            remittance_advice_remark_codes=["N362"],
        ),
        service_line_manual_adjustments=[
            ServiceLineAdjustment(
                created_at=datetime.datetime.fromisoformat(
                    "2023-01-01 00:00:00+00:00",
                ),
                adjustment_group_code="CO",
                adjustment_reason_code="CO",
                adjustment_amount_cents=1000,
                adjustment_note="test_note",
            )
        ],
        related_invoices=[
            Invoice(
                id=uuid.UUID(
                    "901be2f1-41bc-456e-9987-4fe2f84f9d75",
                ),
                created_at=datetime.datetime.fromisoformat(
                    "2023-01-01 00:00:00+00:00",
                ),
                updated_at=datetime.datetime.fromisoformat(
                    "2023-01-01 00:00:00+00:00",
                ),
                organzation_id=uuid.UUID(
                    "f13f73d4-4344-46ea-9d93-33bcffbb9f36",
                ),
                source_id="9B626577-8808-4F28-9ED1-F0DFF0D49BBC",
                source_customer_id="624D1972-8C69-4C2F-AEFA-10856F734DB3",
                patient_external_id="10FED4D6-4C5A-48DF-838A-EEF45A74788D",
                note="test_note",
                due_date="2023-10-10",
                status=InvoiceStatus.DRAFT,
                url="https://example.com",
                customer_invoice_url="https://example.com",
                items=[
                    InvoiceItem(
                        service_line_id=uuid.UUID(
                            "ced00f23-6e68-4678-9dbc-f5aa2969a565",
                        ),
                        amount_cents=500,
                    )
                ],
            )
        ],
        denial_reason=ServiceLineDenialReason(
            reason=DenialReasonContent.AUTHORIZATION_REQUIRED,
        ),
        place_of_service_code=FacilityTypeCode.PHARMACY,
        service_line_id=uuid.UUID(
            "ced00f23-6e68-4678-9dbc-f5aa2969a565",
        ),
        procedure_code="99213",
        quantity="1",
        units=ServiceLineUnits.MJ,
        claim_id=uuid.UUID(
            "026a1fb8-748e-4859-a2d7-3ea9e07d25ae",
        ),
        date_of_service_range=DateRangeOptionalEnd(
            start_date="2023-01-01",
            end_date="2023-01-03",
        ),
        date_of_service=datetime.date.fromisoformat(
            "2023-01-01",
        ),
        end_date_of_service=datetime.date.fromisoformat(
            "2023-01-03",
        ),
        test_results=[
            TestResult(
                result_type=TestResultType.HEMOGLOBIN,
                value=51.0,
            ),
            TestResult(
                result_type=TestResultType.LDL,
                value=110.0,
            ),
        ],
    )
    """

    created_at: dt.datetime
    modifiers: typing.Optional[typing.List[ProcedureModifier]] = None
    charge_amount_cents: typing.Optional[int] = None
    allowed_amount_cents: typing.Optional[int] = None
    insurance_balance_cents: typing.Optional[int] = None
    patient_balance_cents: typing.Optional[int] = None
    paid_amount_cents: typing.Optional[int] = None
    primary_paid_amount_cents: typing.Optional[int] = None
    secondary_paid_amount_cents: typing.Optional[int] = None
    tertiary_paid_amount_cents: typing.Optional[int] = None
    patient_responsibility_cents: typing.Optional[int] = None
    copay_cents: typing.Optional[int] = None
    coinsurance_cents: typing.Optional[int] = None
    deductible_cents: typing.Optional[int] = None
    diagnosis_id_zero: typing.Optional[DiagnosisId] = None
    diagnosis_id_one: typing.Optional[DiagnosisId] = None
    diagnosis_id_two: typing.Optional[DiagnosisId] = None
    diagnosis_id_three: typing.Optional[DiagnosisId] = None
    drug_identification: typing.Optional[DrugIdentification] = None
    service_line_era_data: typing.Optional[ServiceLineEraData] = None
    service_line_manual_adjustments: typing.Optional[typing.List[ServiceLineAdjustment]] = None
    related_invoices: typing.Optional[typing.List[Invoice]] = None
    related_invoice_info: typing.Optional[typing.List[InvoiceInfo]] = None
    denial_reason: typing.Optional[ServiceLineDenialReason] = None
    place_of_service_code: typing.Optional[FacilityTypeCode] = pydantic.Field(default=None)
    """
    837p Loop2300, SV105. 02 for telemedicine, 11 for in-person. Full list [here](https://www.cms.gov/Medicare/Coding/place-of-service-codes/Place_of_Service_Code_Set).
    """

    place_of_service_code_as_submitted: typing.Optional[FacilityTypeCode] = pydantic.Field(default=None)
    """
    837p Loop2300, SV105. 02 for telemedicine, 11 for in-person. Full list [here](https://www.cms.gov/Medicare/Coding/place-of-service-codes/Place_of_Service_Code_Set).
    """

    service_line_id: ServiceLineId
    procedure_code: str
    ordering_provider: typing.Optional[EncounterProvider] = None
    quantity: Decimal = pydantic.Field()
    """
    String representation of a Decimal that can be parsed by most libraries.
    A ServiceLine quantity cannot contain more than one digit of precision.
    Example: 1.1 is valid, 1.11 is not.
    """

    units: ServiceLineUnits
    claim_id: ClaimId
    date_of_service_range: DateRangeOptionalEnd = pydantic.Field()
    """
    A range of dates of service for this service line. If the service line is for a single date, the end date
    will be empty.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    A free-form description to clarify the related data elements and their content. Maps to SV1-01, C003-07 on the 837-P.
    """

    date_of_service: dt.date
    end_date_of_service: typing.Optional[dt.date] = None
    test_results: typing.Optional[typing.List[TestResult]] = pydantic.Field(default=None)
    """
    Contains a list of test results. Test result types may map to MEA-02 on the 837-P (ex: Hemoglobin, Hematocrit).
    No more than 5 MEA-02 test results may be submitted per service line.
    """

    has_epsdt_indicator: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Maps to SV1-11 on the 837-P and Box 24H on the CMS-1500.
    If the value is true, the box will be populated with "Y". Otherwise, the box will not be populated.
    """

    has_family_planning_indicator: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Maps to SV1-12 on the 837-P and Box 24I on the CMS-1500.
    If the value is true, the box will be populated with "Y". Otherwise, the box will not be populated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import BillingNote, BillingNoteBase, BillingNoteId

__all__ = ["BillingNote", "BillingNoteBase", "BillingNoteId"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....organization_providers.resources.v_2.types.organization_provider_id import OrganizationProviderId
from .....payers.resources.v_3.types.payer_uuid import PayerUuid


class InNetworkStatus(UniversalBaseModel):
    routed_payer_uuid: PayerUuid
    routed_billing_provider_id: OrganizationProviderId

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    KeyWithNameAlreadyExistsError,
    Schema,
    SchemaField,
    SchemaGetMultiResponse,
    SchemaInstance,
    SchemaValidationError,
    SchemaValidationError_KeyNameAlreadyExists,
    SchemaValidationError_SchemaNameAlreadyExists,
    SchemaValidationFailure,
    SchemaWithNameAlreadyExistsError,
)
from .errors import SchemaValidationHttpFailure

__all__ = [
    "KeyWithNameAlreadyExistsError",
    "Schema",
    "SchemaField",
    "SchemaGetMultiResponse",
    "SchemaInstance",
    "SchemaValidationError",
    "SchemaValidationError_KeyNameAlreadyExists",
    "SchemaValidationError_SchemaNameAlreadyExists",
    "SchemaValidationFailure",
    "SchemaValidationHttpFailure",
    "SchemaWithNameAlreadyExistsError",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClaimFrequencyTypeCode(str, enum.Enum):
    ORIGINAL = "1"
    REPLACEMENT = "7"
    VOID = "8"
    _UNKNOWN = "__CLAIMFREQUENCYTYPECODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ClaimFrequencyTypeCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        original: typing.Callable[[], T_Result],
        replacement: typing.Callable[[], T_Result],
        void: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ClaimFrequencyTypeCode.ORIGINAL:
            return original()
        if self is ClaimFrequencyTypeCode.REPLACEMENT:
            return replacement()
        if self is ClaimFrequencyTypeCode.VOID:
            return void()
        return _unknown_member(self._value_)
